<?php
/**
 * @file template.php
 */

include_once(drupal_get_path('theme', 'mojo') . '/inc/process.inc');
include_once(drupal_get_path('theme', 'mojo') . '/inc/theme.inc');

// Auto-rebuild the theme registry during theme development.
if (theme_get_setting('mojo_rebuild_registry')) {
  // Rebuild .info data.
  system_rebuild_theme_data();
  // Rebuild theme registry.
  drupal_theme_rebuild();
  drupal_set_message(t('Theme registry is being rebuilt on every page. !link on production sites.', array('!link' => l(t('Turn this off'), 'admin/appearance/settings/mojo#div-mojo-registry'))), 'warning');
}

// Optimize the scope of scripts for front-end performance.
function mojo_js_alter(&$javascript) {
  if (theme_get_setting('mojo_script_optimize')) {
    foreach ($javascript as $key => $script) {
      if ($key != 'sites/all/themes/mojo/js/modernizr-1.7.min.js') {
        $javascript[$key]['scope'] = 'footer';
      }
    }
  }
}

// Add Modernizr.
if (theme_get_setting('mojo_modernizr')) {
  drupal_add_js(drupal_get_path('theme', 'mojo') . '/js/modernizr-1.7.min.js', array('scope' => 'header', 'version' => '1.7', 'every_page' => TRUE));
}

/**
 * Implements hook_html_head_alter.
 */
function mojo_html_head_alter(&$head_elements) {

  // HTML5 charset declaration.
  $head_elements['system_meta_content_type']['#attributes'] = array(
    'charset' => 'utf-8'
  );

  // Force the latest IE rendering engine & Chrome Frame.
  if (theme_get_setting('mojo_include_chrome_frame')) {
    $head_elements['ie_chrome_frame'] = array(
      '#type' => 'html_tag',
      '#tag' => 'meta',
      '#attributes' => array(
        'http-equiv' => 'X-UA-Compatible',
        'content' => 'IE=edge,chrome=1',
      ),
      '#weight' => -1,
    );
  }

  // Optimize mobile viewport.
  if (theme_get_setting('mojo_use_mobile_viewport')) {
    $head_elements['mobile_viewport'] = array(
      '#type' => 'html_tag',
      '#tag' => 'meta',
      '#attributes' => array(
        'name' => 'viewport',
        'content' => theme_get_setting('mojo_mobile_viewport'),
      ),
    );
  }
}
