<?php
/**
 * @file theme-settings.php
 */

function mojo_form_system_theme_settings_alter(&$form, $form_state) {
  $form['javascript'] = array(
    '#type' => 'fieldset',
    '#title' => t('JavaScript settings'),
    '#attributes' => array('id' => 'mojo-js'),
  );
  $form['javascript']['mojo_script_optimize'] = array(
    '#type' => 'checkbox',
    '#title' => t('Move scripts to the bottom.'),
    '#default_value' => theme_get_setting('mojo_script_optimize'),
    '#description' => t('Set the scope of all scripts (except Modernizr) to the footer<br />
                          For more information: !link',
                          array('!link' => l(t('Move Scripts to the Bottom'), 'http://developer.yahoo.com/blogs/ydn/posts/2007/07/high_performanc_5/'))
                          ),
    '#prefix' => '<strong>' . t('Script Performance') . ':</strong>',
  );
  $form['javascript']['mojo_modernizr'] = array(
    '#type' => 'checkbox',
    '#title' => t('Include Modernizr'),
    '#default_value' => theme_get_setting('mojo_modernizr'),
    '#description' => t('Include a reference the the !link JavaScript library.<br />
                          Requires manual download. Place in /sites/all/themes/mojo/js/ directory.',
                          array('!link' => l(t('Modernizr'), 'http://www.modernizr.com'))
                          ),
    '#prefix' => '<strong>' . t('Modernizr') . ':</strong>',
  );
  $form['mojo_breadcrumb'] = array(
    '#type' => 'fieldset',
    '#title' => t('Breadcrumb settings'),
    '#attributes' => array('id' => 'mojo-breadcrumb'),
  );
  $form['mojo_breadcrumb']['mojo_breadcrumb_display'] = array(
    '#type' => 'select',
    '#title' => t('Display breadcrumb'),
    '#default_value' => theme_get_setting('mojo_breadcrumb_display'),
    '#options' => array(
        'yes' => t('Yes'),
        'admin' => t('Only in admin section'),
        'no' => t('No'),
        ),
  );
  $form['mojo_breadcrumb']['mojo_breadcrumb_separator'] = array(
    '#type' => 'textfield',
    '#title' => t('Breadcrumb separator'),
    '#description' => t('Text only. Don’t forget to include spaces.'),
    '#default_value' => theme_get_setting('mojo_breadcrumb_separator'),
    '#size' => 5,
    '#maxlength' => 10,
  );
  $form['mojo_breadcrumb']['mojo_breadcrumb_home'] = array(
    '#type' => 'checkbox',
    '#title' => t('Show home page link in breadcrumb'),
    '#default_value' => theme_get_setting('mojo_breadcrumb_home'),
  );
  $form['mojo_breadcrumb']['mojo_breadcrumb_trailing'] = array(
    '#type' => 'checkbox',
    '#title' => t('Append a separator to the end of the breadcrumb'),
    '#default_value' => theme_get_setting('mojo_breadcrumb_trailing'),
    '#description' => t('Useful when the breadcrumb is placed just before the title.'),
  );
  $form['mojo_breadcrumb']['mojo_breadcrumb_title'] = array(
    '#type' => 'checkbox',
    '#title' => t('Append the content title to the end of the breadcrumb'),
    '#default_value' => theme_get_setting('mojo_breadcrumb_title'),
    '#description' => t('Useful when the breadcrumb is not placed just before the title.'),
  );
  $form['mobile_viewport'] = array(
    '#type' => 'fieldset',
    '#title' => t('Meta tags for mobile devices'),
    '#attributes' => array('id' => 'mojo-mobile-view-port'),
  );
  $form['mobile_viewport']['mojo_use_mobile_viewport'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use a mobile viewport meta tag'),
    '#default_value' => theme_get_setting('mojo_use_mobile_viewport'),
    '#prefix' => '<strong>' . t('Mobile Viewport Fix') . ':</strong>',
  );
  $form['mobile_viewport']['mojo_mobile_viewport'] = array(
    '#type' => 'textfield',
    '#title' => t('Mobile viewport meta tag value'),
    '#default_value' => theme_get_setting('mojo_mobile_viewport'),
    '#description' => t('Suggested default: width=device-width; initial-scale=1.0;<br />
                          For more information: !link',
                          array('!link' => l(t('Viewport Meta Tag'), 'https://developer.mozilla.org/en/Mobile/Viewport_meta_tag'))
                          ),
  );
  $form['mojo_include_chrome_frame'] = array(
    '#type' => 'checkbox',
    '#title' => t('Include Chrome Frame for IE users with Chrome Frame installed'),
    '#default_value' => theme_get_setting('mojo_include_chrome_frame'),
    '#description' => t('Include a meta tag to initialize Chrome Frame. Only affects IE users who already have Chrome Frame installed.'),
    '#prefix' => '<strong>' . t('Chrome Frame') . ':</strong>',
  );
  $form['mojo_rebuild_registry'] = array(
    '#type' => 'checkbox',
    '#title' => t('Rebuild theme registry on every page.'),
    '#default_value' => theme_get_setting('mojo_rebuild_registry'),
    '#description' => t('During theme development, it can be very useful to continuously <a href="!link">rebuild the theme registry</a>. WARNING: this is a huge performance penalty and must be turned off on production websites.', array('!link' => 'http://drupal.org/node/173880#theme-registry')),
    '#prefix' => '<div id="div-mojo-registry"><strong>' . t('Theme registry') . ':</strong>',
    '#suffix' => '</div>',
  );
}
